var datareload = document.querySelectorAll("[data-reload]");

var language = {
    eng: {
        welcome: "Welcome everyone!",
        sokoban_exp: "Sokoban is a game in which the player pushes boxes around in a warehouse, trying to get them to storage locations. Click me for code",
        laby_exp: "It is a maze (as in a garden) formed by paths separated by high hedges. Click me for code",
        chess_exp: "It is played by two opponents on a checkered board with specially designed pieces of contrasting colours, commonly white and black. The objective of the game is to capture the opponent's king. Click me for code",
        example: "Here are the Projects."
    },
    es: {
        welcome: "¡Bienvenidos a todos!",
        sokoban_exp: "Sokoban es un juego en el que el jugador empuja cajas alrededor de un almacén, tratando de llevarlas a los lugares de almacenamiento. Haz clic en el enlace para ver el código:",
        laby_exp: "Es un laberinto (como en un jardín) formado por caminos separados por setos altos. Haz clic en el enlace para ver el código:",
        chess_exp: "Se juega entre dos oponentes en un tablero cuadriculado con piezas especialmente diseñadas de colores contrastantes, comúnmente blanco y negro. El objetivo del juego es capturar el rey del oponente. Haz clic en el enlace para ver el código:",
        example: "Aquí están los proyectos."
    }
};

// set language based on hash in URL
function setLanguageFromHash() {
    var hash = window.location.hash.substring(1);
    if (hash === "eng") {
        hi.textContent = language.eng.welcome;
    } else if (hash === "es") {
        hi.textContent = language.es.welcome;
    }
}

// set language based on language setting in local storage
function setLanguageFromStorage() {
    var lang = localStorage.getItem("lang");
    if (lang) {
        setLanguage(lang);
    }
}

// set language based on selected language
function setLanguage(lang) {
    localStorage.setItem("lang", lang);
    if (lang === "eng") {
        hi.textContent = language.eng.welcome;
        window.location.hash = "eng";
    } else if (lang === "es") {
        hi.textContent = language.es.welcome;
        window.location.hash = "es";
    }
}

// translate a paragraph based on selected language
function translate(lang, paragraphId) {
    var paragraph = document.getElementById(paragraphId);
    if (lang === "eng") {
        paragraph.innerHTML = language.eng[paragraphId];
    } else if (lang === "es") {
        paragraph.innerHTML = language.es[paragraphId];
    }
}

// detect language on page load
if (window.location.hash) {
    setLanguageFromHash();
} else {
    setLanguageFromStorage();
}

// set language on click
for (var i = 0; i < datareload.length; i++) {
    datareload[i].addEventListener("click", function() {
        var lang = this.getAttribute("data-reload");
        setLanguage(lang);
        translate(lang, "sokoban_exp");
        translate(lang, "laby_exp");
        translate(lang, "chess_exp");
        translate(lang, "example");
    });
}
