var language = {
    eng: {
        formTitle: "User Registration Form",
        username: "Username:",
        lastname: "Lastname:",
        gender: "Gender:",
        male: "Male",
        female: "Female",
        email: "Email:",
        phone: "Phone Number:",
        submit: "Submit",
        message: "",
        exist: ""
    },
    es: {
        formTitle: "Formulario de Registro de Usuario",
        username: "Nombre de Usuario:",
        lastname: "Apellido:",
        gender: "Género:",
        male: "Hombre",
        female: "Mujer",
        email: "Correo Electrónico:",
        phone: "Número de Teléfono:",
        submit: "Enviar",
        message: "",
        exist: ""
    }
};


// set language based on hash in URL
function setLanguageFromHash() {
    var hash = window.location.hash.substring(1);
    if (hash === "eng") {
        setLanguage("eng");
    } else if (hash === "es") {
        setLanguage("es");
    }
}

// set language based on language setting in local storage
function setLanguageFromStorage() {
    var lang = localStorage.getItem("lang");
    if (lang) {
        setLanguage(lang);
    }
}

// set language based on selected language
function setLanguage(lang) {
    localStorage.setItem("lang", lang);
    translate(lang, "formTitle");
    translate(lang, "username");
    translate(lang, "lastname");
    translate(lang, "gender");
    translate(lang, "male");
    translate(lang, "female");
    translate(lang, "email");
    translate(lang, "phone");
    translate(lang, "submit");
}


// translate a label based on selected language
function translate(lang, labelId) {
    var label = document.querySelector("label[for='" + labelId + "']");
    if (label) {
        if (lang === "eng") {
            label.textContent = language.eng[labelId];
        } else if (lang === "es") {
            label.textContent = language.es[labelId];
        }
        if (labelId === "submit") {
            label.value = label.textContent;
        }
    }
}


// detect language on page load
if (window.location.hash) {
    setLanguageFromHash();
} else {
    setLanguageFromStorage();
}

// set language on click
var dataReload = document.querySelectorAll("[data-reload]");
for (var i = 0; i < dataReload.length; i++) {
    dataReload[i].addEventListener("click", function() {
        var lang = this.getAttribute("data-reload");
        setLanguage(lang);
    });
}



const form = document.querySelector('form');
const usernameInput = document.getElementById('username');
const lastnameInput = document.getElementById('lastname');
const genderInputs = document.querySelectorAll('[name="gender"]');
const emailInput = document.getElementById('email');
const phoneInput = document.getElementById('phone');
const messageContainer = document.getElementById('message');

// functions will be used in the verifications
function isValidEmail(email) {
    // Basic email validation regex
    const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
    return emailRegex.test(email);
}
  
  function isValidPhone(phone) {
    // Basic phone number validation regex
    const phoneRegex = /^[+]?[(]?[0-9]{1,4}[)]?[-\s.]?[0-9]{3}[-\s.]?[0-9]{4}$/im;
    return phoneRegex.test(phone);
}

function validateForm(event) {
  event.preventDefault();
  let errors = [];
  
  if (usernameInput.value.trim() === '') {
    errors.push('Username is required.');
  }
  
  if (lastnameInput.value.trim() === '') {
    errors.push('Lastname is required.');
  }
  
  let genderChecked = false;
  genderInputs.forEach(input => {
    if (input.checked) {
      genderChecked = true;
    }
  });
  
  if (!genderChecked) {
    errors.push('Gender is required.');
  }
  
  if (emailInput.value.trim() === '') {
    errors.push('Email is required.');
  } else if (!isValidEmail(emailInput.value)) {
    errors.push('Email is invalid.');
  }
  
  if (phoneInput.value.trim() === '') {
    errors.push('Phone number is required.');
  } else if (!isValidPhone(phoneInput.value)) {
    errors.push('Phone number is invalid.');
  }
  
  if (errors.length === 0) {
    // Submit the form
    form.submit();
  } else {
    // Display error messages
    messageContainer.innerHTML = '<ul>' + errors.map(error => `<li>${error}</li>`).join('') + '</ul>'; // in here there are the errors pushed
  }
}



form.addEventListener('submit', validateForm);

